.admin_block_column
{
   width: 800px;
   margin: 5px 0 0 15px;
   padding: 5px 0 0 25px;
   border: 0;
   font: normal 0.88em/140% arial, helvetica, verdana, sans-serif;
   color: #000;
   font-size: 110%;
   vertical-align: top;
   border-bottom-width: 1px;
   border-bottom-style: solid;
   border-bottom-color: #eeeeee;
}

.admin_tools_column
{
   text-align: right
}

.admin_block_view_row1
{
   background-color: #eee;
}

.admin_block_view_row2
{
   background-color: #fff; 
}

#id_label, #id_slug, #id_template 
{
    width: 300px;
}